package java.net;

import java.security.cert.Certificate;
import java.util.jar.Attributes;
import java.util.jar.JarEntry;
import java.util.jar.Manifest;
import java.io.IOException;
import java.util.jar.JarFile;
import sun.net.www.ParseUtil;

public abstract class JarURLConnection extends URLConnection
{
    private URL jarFileURL;
    private String entryName;
    protected URLConnection jarFileURLConnection;
    
    protected JarURLConnection(URL url) throws MalformedURLException {
        super(url);
        this.parseSpecs(url);
    }
    
    private void parseSpecs(URL url) throws MalformedURLException {
        String file = url.getFile();
        int index = file.indexOf("!/");
        if (index == -1) {
            throw new MalformedURLException("no !/ found in url spec:" + file);
        }
        this.jarFileURL = new URL(file.substring(0, index++));
        this.entryName = null;
        if (++index != file.length()) {
            this.entryName = file.substring(index, file.length());
            this.entryName = ParseUtil.decode(this.entryName);
        }
        return;
    }
    
    public URL getJarFileURL() {
        return this.jarFileURL;
    }
    
    public String getEntryName() {
        return this.entryName;
    }
    
    public abstract JarFile getJarFile() throws IOException;
    
    public Manifest getManifest() throws IOException {
        return this.getJarFile().getManifest();
    }
    
    public JarEntry getJarEntry() throws IOException {
        return this.getJarFile().getJarEntry(this.entryName);
    }
    
    public Attributes getAttributes() throws IOException {
        JarEntry jarEntry = this.getJarEntry();
        return (jarEntry != null) ? jarEntry.getAttributes() : null;
    }
    
    public Attributes getMainAttributes() throws IOException {
        Manifest manifest = this.getManifest();
        return (manifest != null) ? manifest.getMainAttributes() : null;
    }
    
    public Certificate[] getCertificates() throws IOException {
        JarEntry jarEntry = this.getJarEntry();
        return (jarEntry != null) ? jarEntry.getCertificates() : null;
    }
}
